@@ -6,15 +6,15 @@ function (ipsi = -9, c = -1.345, h1 = -1.7, h2 = -3.4, h3 = -8.5,
 
 #   if(!exists(".dFv", , envir=.GlobalEnv)) dfvals()
 
-    f.res <- .Fortran("dfcomn", ipsi = to.integer(ipsi), c = to.single(c),
-        h1 = to.single(h1), h2 = to.single(h2), h3 = to.single(h3),
-        xk = to.single(xk), d = to.single(d), beta = to.single(beta),
-        bet0 = to.single(bet0), iucv = to.integer(iucv), a2 = to.single(a2),
-        b2 = to.single(b2), chk = to.single(chk), ckw = to.single(ckw),
-        bb = to.single(bb), bt = to.single(bt), cw = to.single(cw),
-        em = to.single(em), cr = to.single(cr), vk = to.single(vk),
-        np = to.integer(np), enu = to.single(nu), v7 = to.single(v7),
-        iwww = to.integer(iwww))
+#   f.res <- .Fortran("dfcomn", ipsi = to.integer(ipsi), c = to.single(c),
+#       h1 = to.single(h1), h2 = to.single(h2), h3 = to.single(h3),
+#       xk = to.single(xk), d = to.single(d), beta = to.single(beta),
+#       bet0 = to.single(bet0), iucv = to.integer(iucv), a2 = to.single(a2),
+#       b2 = to.single(b2), chk = to.single(chk), ckw = to.single(ckw),
+#       bb = to.single(bb), bt = to.single(bt), cw = to.single(cw),
+#       em = to.single(em), cr = to.single(cr), vk = to.single(vk),
+#       np = to.integer(np), enu = to.single(nu), v7 = to.single(v7),
+#       iwww = to.integer(iwww))
     f.res <- .Fortran("dfcomn2", ipsi = to.integer(ipsi), c = to.single(c),
         h1 = to.single(h1), h2 = to.single(h2), h3 = to.single(h3),
         xk = to.single(xk), d = to.single(d), beta = to.single(beta),
